@@ -35,11 +35,6 @@ import pickle
 import shutil
 
 # home grown
-from . import version
-from .config import *
-
-from . import csvwt
-
 
 # pypi
 # github
@@ -67,12 +62,14 @@ def getagtable(agegradewb):
     agegradedata = {}
     
     # convert the workbook to csv
-    c = csvwt.Xls2Csv(agegradewb)
+    from .csvwt import Xls2Csv
+
+    c = Xls2Csv(agegradewb)
     gen2sheet = {'F':'Women','M':'Men'}
     sheets = c.getfiles()
     
     for gen in ['F','M']:
-        SHEET = open(sheets[gen2sheet[gen]],'rb')
+        SHEET = open(sheets[gen2sheet[gen]],'r',newline='')
         sheet = csv.DictReader(SHEET)
         
         # convert fields to keys - e.g., '5.0' -> 5, skipping non-numeric keys
@@ -131,7 +128,9 @@ class AgeGrade():
     #----------------------------------------------------------------------
     def __init__(self,agegradewb=None,DEBUG=None):
     #----------------------------------------------------------------------
+        from .config import CONFIGDIR
         self.DEBUG = DEBUG
+
         # write header for csv file.  Must match order within self.agegrade if self.DEBUG statement
         if self.DEBUG:
             self.DEBUG.write('distmeters,age,gen,openstd,factor,time,agresult,agpercentage\n')
@@ -270,6 +269,81 @@ class AgeGrade():
             self.DEBUG.write('{},{},{},{},{},{},{},{}\n'.format(distmeters,age,gen,openstd,factor,time,agresult,agpercentage))
         return agpercentage,agresult,factor
 
+    #----------------------------------------------------------------------
+    def result(self,age,gen,distmiles,agpc):
+    #----------------------------------------------------------------------
+        '''
+        returns age grade statistics for the indicated age, gender, distance, result time
+
+        :param age: integer age.  If float is supplied, integer portion is used (no interpolation of fractional age)
+        :param gen: gender - M or F
+        :param distmiles: distance (miles)
+        :param agpc: age grade percentage - between 0 and 100
+
+        :rtype: result in seconds
+        '''
+
+        # check for some input errors
+        gen = gen.upper()
+        if gen not in ['F','M']:
+            raise parameterError('gen must be M or F')
+
+        # number of meters in a mile -- close enough for this data set
+        mpermile = 1609.344
+
+        # some known conversions
+        cdist = {26.2:42195,13.1:21098}
+
+        # determine distance in meters
+        if distmiles in cdist:
+            distmeters = cdist[distmiles]
+        else:
+            distmeters = distmiles*mpermile
+
+        # check distance within range.  Make min and max float so exception format specification works
+        distlist = list(self.agegradedata[gen].keys())
+        minmeters = min(distlist)*1.0
+        maxmeters = max(distlist)*1.0
+        if distmeters < minmeters or distmeters > maxmeters:
+            raise parameterError('distmiles must be between {0:f0.3} and {1:f0.1}'.format(minmeters/mpermile,maxmeters/mpermile))
+
+        # interpolate factor and openstd based on distance for this age
+        age = int(age)
+        if age in range(5,100):
+            factor,openstd = self.getfactorstd(age,gen,distmeters)
+
+        # extrapolate for ages < 5
+        elif age < 5:
+            # don't do extrapolation
+            if True:
+                factor,openstd = self.getfactorstd(5,gen,distmeters)
+
+            else:
+                age1 = 5
+                age2 = 6
+                factor1,openstd1 = self.getfactorstd(age1,gen,distmeters)
+                factor2,openstd2 = self.getfactorstd(age2,gen,distmeters)
+                factor = factor1 + (1.0*(age-age1)/(age2-age1))*(factor2-factor1)
+                openstd = openstd1 + (1.0*(age-age1)/(age2-age1))*(openstd2-openstd1)
+
+         # extrapolate for ages > 99
+        elif age > 99:
+            if True:
+                factor,openstd = self.getfactorstd(99,gen,distmeters)
+
+            # don't do extrapolation
+            else:
+                age1 = 98
+                age2 = 99
+                factor1,openstd1 = self.getfactorstd(age1,gen,distmeters)
+                factor2,openstd2 = self.getfactorstd(age2,gen,distmeters)
+                factor = factor1 + (1.0*(age-age1)/(age2-age1))*(factor2-factor1)
+                openstd = openstd1 + (1.0*(age-age1)/(age2-age1))*(openstd2-openstd1)
+
+        # return result
+        time = (openstd/factor)/(agpc/100.0)
+        return time
+
 #----------------------------------------------------------------------
 def main(): 
 #----------------------------------------------------------------------
@@ -280,9 +354,12 @@ def main():
     --agworkbook creates an agconfigfile and puts it in the configuration directory.
     --agconfigfile simply places the indicated file into the configuration directory.
     '''
-    
-    parser = argparse.ArgumentParser(description=descr,formatter_class=argparse.RawDescriptionHelpFormatter,
-                                     version='{0} {1}'.format('loutilities',version.__version__))
+
+    from . import version
+    from .config import CONFIGDIR
+
+    parser = argparse.ArgumentParser(prog='loutilities', description=descr,formatter_class=argparse.RawDescriptionHelpFormatter)
+    parser.add_argument('-v', '--version', action='version', version='%(prog)s {}'.format(version.__version__))
     parser.add_argument('-a','--agworkbook',help='filename of age grade workbook.', default=None)
     parser.add_argument('-c','--agconfigfile',help='filename of age grade config file',default=None)
     args = parser.parse_args()
